<?php defined('BASEPATH') OR exit('No direct script access allowed'); ?>

ERROR - 2024-06-14 03:36:22 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-06-14 08:27:57 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
ERROR - 2024-06-14 08:27:58 --> 404 Page Not Found: Robotstxt/index
ERROR - 2024-06-14 08:27:58 --> $config['composer_autoload'] is set to TRUE but /home/artechsy/public_html/live-education.artech-system.com/application/vendor/autoload.php was not found.
